==> gimp-1.3.12.tar.bz2: gimp-1.3.12/plug-ins/gfig/gfig-stock.h <==
/*
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This is a plug-in for the GIMP.
 *
 * Generates images containing vector type drawings.
 *
 * Copyright (C) 1997 Andy Thomas  <alt@picnic.demon.co.uk>
 *               2003 Sven Neumann  <sven@gimp.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GFIG_STOCK_H__
#define __GFIG_STOCK_H__


#define GFIG_STOCK_BEZIER         "gfig-bezier"
#define GFIG_STOCK_CIRCLE         "gfig-circle"
#define GFIG_STOCK_COPY_OBJECT    "gfig-copy-object"
#define GFIG_STOCK_CURVE          "gfig-curve"
#define GFIG_STOCK_DELETE_OBJECT  "gfig-delete"
#define GFIG_STOCK_ELLIPSE        "gfig-ellipse"
#define GFIG_STOCK_LINE           "gfig-line"
#define GFIG_STOCK_MOVE_OBJECT    "gfig-move-object"
#define GFIG_STOCK_MOVE_POINT     "gfig-move-point"
#define GFIG_STOCK_POLYGON        "gfig-polygon"
#define GFIG_STOCK_SPIRAL         "gfig-spiral"
#define GFIG_STOCK_STAR           "gfig-star"

#define GFIG_STOCK_LOGO           "gfig-logo"


void  gfig_stock_init (void);


#endif /* __GFIG_STOCK_H__ */

==> gimp-2.3.12.tar.bz2: gimp-2.3.12/plug-ins/gfig/gfig-stock.h <==
/*
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This is a plug-in for the GIMP.
 *
 * Generates images containing vector type drawings.
 *
 * Copyright (C) 1997 Andy Thomas  <alt@picnic.demon.co.uk>
 *               2003 Sven Neumann  <sven@gimp.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GFIG_STOCK_H__
#define __GFIG_STOCK_H__

#define GFIG_STOCK_BEZIER         "gfig-bezier"
#define GFIG_STOCK_CIRCLE         "gfig-circle"
#define GFIG_STOCK_COPY_OBJECT    "gfig-copy-object"
#define GFIG_STOCK_CURVE          "gfig-curve"
#define GFIG_STOCK_DELETE_OBJECT  "gfig-delete"
#define GFIG_STOCK_ELLIPSE        "gfig-ellipse"
#define GFIG_STOCK_LINE           "gfig-line"
#define GFIG_STOCK_MOVE_OBJECT    "gfig-move-object"
#define GFIG_STOCK_MOVE_POINT     "gfig-move-point"
#define GFIG_STOCK_POLYGON        "gfig-polygon"
#define GFIG_STOCK_RECTANGLE      "gfig-rectangle"
#define GFIG_STOCK_SELECT_OBJECT  "gfig-select-object"
#define GFIG_STOCK_SHOW_ALL       "gfig-show-all"
#define GFIG_STOCK_SPIRAL         "gfig-spiral"
#define GFIG_STOCK_STAR           "gfig-star"

void  gfig_stock_init (void);

#endif /* __GFIG_STOCK_H__ */
